EXPORTS
	"_._13CBioTestUtils" @ 1 NONAME ; CBioTestUtils::~CBioTestUtils(void)
	CreateBIOEntryL__13CBioTestUtilsR7TDesC1615TBIOMessageType @ 2 NONAME ; CBioTestUtils::CreateBIOEntryL(TDesC16 &, TBIOMessageType)
	CreateBioServerMtmRegL__13CBioTestUtils @ 3 NONAME ; CBioTestUtils::CreateBioServerMtmRegL(void)
	CreateParserL__13CBioTestUtilsl @ 4 NONAME ; CBioTestUtils::CreateParserL(long)
	CreateParserTypeL__13CBioTestUtilsl @ 5 NONAME ; CBioTestUtils::CreateParserTypeL(long)
	EmptyInboxMessagesL__13CBioTestUtils @ 6 NONAME ; CBioTestUtils::EmptyInboxMessagesL(void)
	GenerateMessagesL__13CBioTestUtils @ 7 NONAME ; CBioTestUtils::GenerateMessagesL(void)
	GenerateMessagesL__13CBioTestUtilsRC7TDesC16i @ 8 NONAME ; CBioTestUtils::GenerateMessagesL(TDesC16 const &, int)
	LogCurrentMessageTypeL__13CBioTestUtilsl @ 9 NONAME ; CBioTestUtils::LogCurrentMessageType(long)
	LogExtractedFieldsL__13CBioTestUtilsl @ 10 NONAME ; CBioTestUtils::LogExtractedFieldsL(long)
	MessageBodyL__13CBioTestUtilsl @ 11 NONAME ; CBioTestUtils::MessageBodyL(long)
	NewLC__13CBioTestUtilsR5RTest @ 12 NONAME ; CBioTestUtils::NewLC(RTest &)
	NewLC__13CBioTestUtilsR5RTesti @ 13 NONAME ; CBioTestUtils::NewLC(RTest &, int)
	NewL__13CBioTestUtilsR5RTest @ 14 NONAME ; CBioTestUtils::NewL(RTest &)
	NewL__13CBioTestUtilsR5RTesti @ 15 NONAME ; CBioTestUtils::NewL(RTest &, int)
	ParsedFieldArray__13CBioTestUtils @ 16 NONAME ; CBioTestUtils::ParsedFieldArray(void)
	SetBIOServiceIdL__13CBioTestUtils @ 17 NONAME ; CBioTestUtils::SetBIOServiceIdL(void)
	SetSessionPath__13CBioTestUtilsRC7TDesC16 @ 18 NONAME ; CBioTestUtils::SetSessionPath(TDesC16 const &)
	CreateBIOEntryFromFileL__13CBioTestUtilsRC7TDesC1615TBIOMessageType @ 19 NONAME ; CBioTestUtils::CreateBIOEntryFromFileL(TDesC16 const &, TBIOMessageType)
	DoAppendVariantName__13CBioTestUtilsR6TDes16 @ 20 NONAME R3UNUSED ; CBioTestUtils::DoAppendVariantName(TDes16 &)
	SetMessageType__13CBioTestUtilsRC7TDesC16 @ 21 NONAME R3UNUSED ; CBioTestUtils::SetMessageType(TDesC16 const &)

